.. _roadmap-page:

.. include:: abbreviation.txt
.. include:: project-links.txt

=========
 Roadmap
=========

`Roadmap @Github <https://github.com/FabriceSalvaire/PySpice/milestones>`_

V1.3
----

`V1.3 Roadmap @Github <https://github.com/FabriceSalvaire/PySpice/milestone/4>`_

* to be defined

V2
--

`V2 Roadmap @Github <https://github.com/FabriceSalvaire/PySpice/milestone/1>`_

* `Implement missing analyses  <https://github.com/FabriceSalvaire/PySpice/issues/63>`_
* `Implement missing devices <https://github.com/FabriceSalvaire/PySpice/issues/64>`_

.. What are the planned features ?

Some ideas for the future
-------------------------

These features are planned in the future:

* Improve the analyse experience
* Complete Spice expression parser
* Complete missing devices and simulations
* Jupyter notebook examples

Some other ideas are:

* Implement a Modelica backend. |Modelica|_ is a very interesting solution for transient analysis.

The implementation of a simulator in Python is not planned since it would be too challenging to
release a full featured and proved simulator. However you could look at the project `Ahkab
<https://ahkab.github.io/ahkab>`_ which aims to implement such Python based simulator.  Notice any
of the projects like Ngspice or Ahkab are compliant with industrial quality assurance processes.
